#ifndef JOB_IMPORTPLAYLIST_H
#define JOB_IMPORTPLAYLIST_H

#include "prokyon.h"
#include "jobbase.h"

#include <qstring.h>

class Job_ImportPlaylist : public JobBase  {
public:
    Job_ImportPlaylist(QString);

    int type() {
        return JOB_IMPORT_PLAYLIST;
    }

    void run();

    ~Job_ImportPlaylist();

private:
    QString fileName;

};
#endif
